from typing import Annotated, Optional, List
from pydantic import Field
from .client import _call_api
from . import mcp

@mcp.tool()
def query_quota(
    region: Annotated[str, Field(description="地域")],
    limit: Annotated[int, Field(description="页长度，默认20")] = 100,
    offset: Annotated[int, Field(description="偏移量，默认0")] = 0,
    product_code: Annotated[str, Field(description="产品码")] = "cvm-instance",
    region_alias: Annotated[Optional[str], Field(description="地域别名")] = None,
    zone_id: Annotated[Optional[List[int]], Field(description="可用区ID列表")] = None,
    app_id: Annotated[Optional[List[str]], Field(description="用户AppID列表")] = None,
    pay_mode: Annotated[Optional[List[str]], Field(description="计费模式列表")] = None,
    instance_type: Annotated[Optional[List[str]], Field(description="实例类型列表")] = None,
    instance_family: Annotated[Optional[List[str]], Field(description="机型族列表")] = None
) -> str:
    """查询配额信息
    
    Args:
        region: 地域
        product_code: 产品码
        limit: 页长度，默认20
        offset: 偏移量，默认0
        region_alias: 地域别名
        zone_id: 可用区ID列表
        app_id: 用户AppID列表
        pay_mode: 计费模式列表
        instance_type: 实例类型列表
        instance_family: 机型族列表
        
    Returns:
        str: 配额信息的JSON字符串
    """
    params = {
        "region": region,
        "productCode": product_code,
        "limit": limit,
        "offset": offset
    }
    if region_alias is not None:
        params["regionAlias"] = region_alias
    if zone_id is not None:
        params["zoneId"] = zone_id
    if app_id is not None:
        params["appId"] = app_id
    if pay_mode is not None:
        params["payMode"] = pay_mode
    if instance_type is not None:
        params["instanceType"] = instance_type
    if instance_family is not None:
        params["instanceFamily"] = instance_family
    return _call_api("/data360/quota/query", params)

@mcp.tool()
def query_instance_families(
    instance_family: Annotated[Optional[str], Field(description="实例族名称")] = None,
    states: Annotated[Optional[List[str]], Field(description="实例族状态列表")] = None,
    supply_states: Annotated[Optional[List[str]], Field(description="实例族供货状态列表")] = None,
    instance_categories: Annotated[Optional[List[str]], Field(description="实例分类列表")] = None,
    type_names: Annotated[Optional[List[str]], Field(description="类型名称列表")] = None,
    instance_class: Annotated[Optional[str], Field(description="实例类型分类")] = None,
    page_number: Annotated[int, Field(description="页码")] = 1,
    page_size: Annotated[int, Field(description="每页数量")] = 20
) -> str:
    """查询机型族信息
    
    Args:
        instance_family: 实例族名称
        states: 实例族状态列表
        supply_states: 实例族供货状态列表
        instance_categories: 实例分类列表
        type_names: 类型名称列表
        instance_class: 实例类型分类
        page_number: 页码
        page_size: 每页数量
        
    Returns:
        查询结果的JSON字符串
    """
    params = {
        "pageNumber": page_number,
        "pageSize": page_size,
        "display": True
    }
    if instance_family:
        params["instanceFamily"] = instance_family
    if states:
        params["state"] = states
    if supply_states:
        params["supplyState"] = supply_states
    if instance_categories:
        params["instanceCategory"] = instance_categories
    if type_names:
        params["typeName"] = type_names
    if instance_class:
        params["instanceClass"] = instance_class
    return _call_api("/data360/instance-family", params)

@mcp.tool()
def get_instance_count(
    region: Annotated[str, Field(description="地域")],
    next_token: Annotated[str, Field(description="分页token")] = "",
    limit: Annotated[int, Field(description="每页数量")] = 20,
    app_ids: Annotated[Optional[List[int]], Field(description="AppID列表")] = None,
    uins: Annotated[Optional[List[str]], Field(description="UIN列表")] = None,
    instance_types: Annotated[Optional[List[str]], Field(description="实例类型列表")] = None,
    instance_families: Annotated[Optional[List[str]], Field(description="实例族列表")] = None
) -> str:
    """查询实例数量
    
    Args:
        region: 地域
        next_token: 分页token
        limit: 每页数量
        app_ids: AppID列表
        uins: UIN列表
        instance_types: 实例类型列表
        instance_families: 实例族列表
        
    Returns:
        查询结果的JSON字符串
    """
    params = {
        "hasTotalCount": True,
        "nextToken": next_token,
        "limit": limit,
        "region": region
    }
    if app_ids:
        params["appId"] = app_ids
    if uins:
        params["uin"] = uins
    if instance_types:
        params["instanceType"] = instance_types
    if instance_families:
        params["instanceFamily"] = instance_families
    return _call_api("/data360/instance/count", params)

@mcp.tool()
def query_instances(
    region: Annotated[str, Field(description="地域")],
    next_token: Annotated[str, Field(description="分页token")] = "",
    limit: Annotated[int, Field(description="每页数量")] = 20,
    app_ids: Annotated[Optional[List[int]], Field(description="AppID列表")] = None,
    uins: Annotated[Optional[List[str]], Field(description="UIN列表")] = None,
    instance_types: Annotated[Optional[List[str]], Field(description="实例类型列表")] = None,
    instance_families: Annotated[Optional[List[str]], Field(description="实例族列表")] = None
) -> str:
    """查询实例列表
    
    Args:
        region: 地域
        next_token: 分页token
        limit: 每页数量
        app_ids: AppID列表
        uins: UIN列表
        instance_types: 实例类型列表
        instance_families: 实例族列表
        
    Returns:
        查询结果的JSON字符串
    """
    params = {
        "hasTotalCount": True,
        "nextToken": next_token,
        "limit": limit,
        "region": region
    }
    if app_ids:
        params["appId"] = app_ids
    if uins:
        params["uin"] = uins
    if instance_types:
        params["instanceType"] = instance_types
    if instance_families:
        params["instanceFamily"] = instance_families
    return _call_api("/data360/instance", params)

@mcp.tool()
def get_instance_details(
    region: Annotated[str, Field(description="地域")],
    instance_id: Annotated[Optional[List[str]], Field(description="实例ID")] = None
) -> str:
    """查询实例详情
    
    Args:
        region: 地域
        instance_id: 实例ID
        
    Returns:
        查询结果的JSON字符串
    """
    params = {
        "instanceId": instance_id,
        "region": region
    }
    return _call_api("/data360/instance/detail", params)

@mcp.tool()
def get_user_owned_grid(
    app_id: Annotated[int, Field(description="APPID")],
    region: Annotated[Optional[List[str]], Field(description="地域列表")] = None
) -> str:
    """获取用户拥有的网格列表
    
    Args:
        app_id: APPID
        region: 地域列表
        
    Returns:
        str: 网格列表的JSON字符串
    """
    params = {
        "appId": app_id,
        "region": region
    }
    return _call_api("/data360/user360/grid", params)

@mcp.tool()
def get_user_owned_instances(
    app_id: Annotated[int, Field(description="APPID")],
    region: Annotated[Optional[List[str]], Field(description="地域列表")] = None
) -> str:
    """获取用户拥有的实例列表
    
    Args:
        app_id: APPID
        region: 地域列表
        
    Returns:
        str: 实例列表的JSON字符串
    """
    params = {
        "appId": app_id,
        "region": region
    }
    return _call_api("/data360/user360/instance", params)

@mcp.tool()
def get_customer_account_info(
    customer_ids: Annotated[List[str], Field(description="客户ID列表")]
) -> str:
    """获取客户账号信息
    
    Args:
        customer_ids: 客户ID列表
        
    Returns:
        str: 客户账号信息的JSON字符串
    """
    return _call_api("/data360/customer/batch-query-account-info", customer_ids) 